==> blender_4.0.2+dfsg.orig.tar.xz: blender-4.0.2/source/blender/blenloader/intern/versioning_dna.cc <==
/* SPDX-FileCopyrightText: 2023 Blender Authors
 *
 * SPDX-License-Identifier: GPL-2.0-or-later */

/** \file
 * \ingroup blenloader
 *
 * Apply edits to DNA at load time to behave as if old files were written with new names.
 */

#include "BLI_compiler_attrs.h"
#include "BLI_utildefines.h"

#include "DNA_genfile.h"
#include "DNA_listBase.h"

#include "BLO_readfile.h"
#include "readfile.hh"

void blo_do_versions_dna(SDNA *sdna, const int versionfile, const int subversionfile)
{
#define DNA_VERSION_ATLEAST(ver, subver) \
  (versionfile > (ver) || (versionfile == (ver) && (subversionfile >= (subver))))

  if (!DNA_VERSION_ATLEAST(280, 2)) {
    /* Version files created in the 'blender2.8' branch
     * between October 2016, and November 2017 (>=280.0 and < 280.2). */
    if (versionfile >= 280) {
      DNA_sdna_patch_struct_by_name(sdna, "SceneLayer", "ViewLayer");
      DNA_sdna_patch_struct_by_name(sdna, "SceneLayerEngineData", "ViewLayerEngineData");
      DNA_sdna_patch_struct_member_by_name(
          sdna, "FileGlobal", "cur_render_layer", "cur_view_layer");
      DNA_sdna_patch_struct_member_by_name(
          sdna, "ParticleEditSettings", "scene_layer", "view_layer");
      DNA_sdna_patch_struct_member_by_name(sdna, "Scene", "active_layer", "active_view_layer");
      DNA_sdna_patch_struct_member_by_name(sdna, "Scene", "render_layers", "view_layers");
      DNA_sdna_patch_struct_member_by_name(sdna, "WorkSpace", "render_layer", "view_layer");
    }
  }

#undef DNA_VERSION_ATLEAST
}

==> blender_4.3.2+dfsg.orig.tar.xz: blender-4.3.2/source/blender/blenloader/intern/versioning_dna.cc <==
/* SPDX-FileCopyrightText: 2023 Blender Authors
 *
 * SPDX-License-Identifier: GPL-2.0-or-later */

/** \file
 * \ingroup blenloader
 *
 * Apply edits to DNA at load time to behave as if old files were written with new names.
 */

#include "BLI_compiler_attrs.h"
#include "BLI_utildefines.h"

#include "DNA_genfile.h"
#include "DNA_listBase.h"

#include "BLO_readfile.hh"
#include "readfile.hh"

void blo_do_versions_dna(SDNA *sdna, const int versionfile, const int subversionfile)
{
#define DNA_VERSION_ATLEAST(ver, subver) \
  (versionfile > (ver) || (versionfile == (ver) && (subversionfile >= (subver))))

  if (!DNA_VERSION_ATLEAST(280, 2)) {
    /* Version files created in the 'blender2.8' branch
     * between October 2016, and November 2017 (>=280.0 and < 280.2). */
    if (versionfile >= 280) {
      DNA_sdna_patch_struct_by_name(sdna, "SceneLayer", "ViewLayer");
      DNA_sdna_patch_struct_by_name(sdna, "SceneLayerEngineData", "ViewLayerEngineData");
      DNA_sdna_patch_struct_member_by_name(
          sdna, "FileGlobal", "cur_render_layer", "cur_view_layer");
      DNA_sdna_patch_struct_member_by_name(
          sdna, "ParticleEditSettings", "scene_layer", "view_layer");
      DNA_sdna_patch_struct_member_by_name(sdna, "Scene", "active_layer", "active_view_layer");
      DNA_sdna_patch_struct_member_by_name(sdna, "Scene", "render_layers", "view_layers");
      DNA_sdna_patch_struct_member_by_name(sdna, "WorkSpace", "render_layer", "view_layer");
    }
  }

#undef DNA_VERSION_ATLEAST
}
